@@ -190,6 +190,10 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	GP_DEBUG ("width is %i\n", w);
 	h = jl2005a_get_pic_height(camera->port);
 	GP_DEBUG ("height is %i\n", h);
+
+	/* sanity check against bad usb devices */
+	if ((w ==0) || (w > 1024) || (h == 0) || (h > 1024)) return GP_ERROR;
+
 	/* Image data to be downloaded contains header and footer bytes */
 	data = malloc (b+14);
 	if (!data) return GP_ERROR_NO_MEMORY;
@@ -224,6 +228,12 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			compressed = 1;
 			h = 288;
 		}
+
+	/* sanity check the sizes, as the ahd bayer algorithm does not like very small height / width */
+	if ((h < 72) || (w < 176)) {
+		status = GP_ERROR;
+		goto end;
+	}
 	p_data = malloc( w*h );
 	if (!p_data) {
 		status =  GP_ERROR_NO_MEMORY;
@@ -247,7 +257,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	size = strlen ((char *)ppm);
 	ptr = ppm + size;
 	size = size + (w * h * 3);
-	GP_DEBUG ("size = %i\n", size);
+	GP_DEBUG ("size = %i, w = %d, h = %d\n", size, w,h );
 	gp_ahd_decode (p_data, w , h, ptr, BAYER_TILE_BGGR);
 
 	free(p_data);
