@@ -66,6 +66,7 @@ int lg_gsm_init (GPPort *port, Model *model, Info *info)
 
 	/* This information, too. */
 	memcpy (info, &firmware[6], 40);
+	info[39] = 0;
 
 	GP_DEBUG("info = %s\n", info);
 	/*GP_DEBUG("info[20] = 0x%x\n", firmware[26]);*/
@@ -204,11 +205,11 @@ int lg_gsm_read_picture_data (GPPort *port, char *data, int size, int n)
 
 int lg_gsm_list_files (GPPort *port, CameraList *list) 
 {
-	int num_pics;
+	unsigned int num_pics;
 	int i;	
 
 	char oknok[6];
-	char photonumber[22];
+	unsigned char photonumber[22];
 	char photolist[142000]; /* max_photos * 142 */
 	char name[44];
 	char value[88];
@@ -231,10 +232,13 @@ int lg_gsm_list_files (GPPort *port, CameraList *list)
 	/* lsphoto : write 0x04000800000040000000ffffffff */
 	MSGWRITE(port, 0x13, 0xe, 0x0, "", 0);
 	WRITE(port, list_all_photo, 0xe);
-	READ(port, photonumber, 0x16);
+	READ(port, (char*)photonumber, 0x16);
 
 	num_pics=photonumber[20]+256*photonumber[21];
 
+	GP_DEBUG ("num_pics = %d\n", num_pics);
+	if (num_pics > 1000) return GP_ERROR;
+
 	/* increase timeout to 20s */
 	/*port->timeout=20000;*/
 	/* read 142 * nb_photos */
@@ -243,7 +247,9 @@ int lg_gsm_list_files (GPPort *port, CameraList *list)
 	for (i = 0; i < num_pics; i++){
 		/* sprintf( name, "lg_gsm_pic%03i.jpg", i ); */
 		memcpy(name,&photolist[6+142*i],44);
+		name[43] = 0;
 		memcpy(value,&photolist[50+142*i],80);
+		value[80] = 0;
 		gp_list_append(list, name, value);
 	}
 	/* restore timeout to 5s */
