@@ -26,7 +26,7 @@
 /* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
 /* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 #include <string.h>
@@ -62,6 +62,7 @@ free_files (CameraPrivateLibrary *pl)
 			if(pl->files[i].thumb) free (pl->files[i].thumb);
 		}
 		free(pl->files);
+		pl->files = NULL;
 	}
 }
 
@@ -332,7 +333,7 @@ spca50x_flash_get_file_name (CameraPrivateLibrary *pl, int index, char *name)
 {
 	uint8_t *p;
 	if (pl->bridge == BRIDGE_SPCA500) {
-		char p[14];
+		char p[30];
 		int w, h, type, size;
 
 		memset (p, 0, sizeof(p));
@@ -351,7 +352,7 @@ spca50x_flash_get_file_name (CameraPrivateLibrary *pl, int index, char *name)
 		else{
 			snprintf (p, sizeof(p), "Unknown");
 		}
-		memcpy (name, p, sizeof(p) );
+		strcpy (name, p);
 	} else {
 		if (pl->fw_rev == 1) {
 			p = pl->flash_toc + index*2*32;
