@@ -269,7 +269,40 @@ gp_port_vusb_msg_read_lib(GPPort *port, int request, int value, int index,
 static int
 gp_port_vusb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 {
+#ifdef FUZZ_PTP
 	if ((idvendor == 0x04b0) && (idproduct == 0x0437)) { /* Nikon D750 */
+#else
+	GPPortInfo info;
+	char	*path, *s;
+	static unsigned short vendor, product;
+	int	fd;
+
+	static char *lastpath = NULL;
+
+	gp_port_get_info (port, &info);
+	gp_port_info_get_path (info, &path);
+
+	if (!lastpath || strcmp(path, lastpath)) {
+		gp_log(GP_LOG_DEBUG,__FUNCTION__,"(path=%s)", path); 
+		if (lastpath) {
+			free(lastpath);
+		}
+		lastpath = strdup(path);
+
+		s = strchr(path, ':')+1;
+		fd = open(s, O_RDONLY);
+		vendor = product = 0;
+		if (fd != -1) {
+			if (-1 == read( fd, &vendor, 2))
+				gp_log(GP_LOG_DEBUG,__FUNCTION__,"could not read vendor"); 
+			if (-1 == read( fd, &product, 2))
+				gp_log(GP_LOG_DEBUG,__FUNCTION__,"could not read product"); 
+			close(fd);
+		}
+	}
+
+	if ((idvendor == vendor) && (idproduct == product)) {
+#endif
                 port->settings.usb.config	= 1;
                 port->settings.usb.interface	= 1;
                 port->settings.usb.altsetting	= 1;
@@ -280,7 +313,7 @@ gp_port_vusb_find_device_lib(GPPort *port, int idvendor, int idproduct)
                 port->settings.usb.maxpacketsize = 512;
 		return GP_OK;
 	}
-	/* gp_log(GP_LOG_DEBUG,__FUNCTION__,"(0x%04x,0x%04x)", idvendor, idproduct); */
+	gp_log(GP_LOG_DEBUG,__FUNCTION__,"(0x%04x,0x%04x)", idvendor, idproduct); 
         return GP_ERROR_IO_USB_FIND;
 }
 
@@ -289,6 +322,7 @@ gp_port_vusb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 {
 	gp_log(GP_LOG_DEBUG,__FUNCTION__,"(0x%02x,0x%02x,0x%02x)", class, subclass, protocol);
 
+#ifdef FUZZ_PTP
 	if ((class == 6) && (subclass == 1) && (protocol == 1)) {
                 port->settings.usb.config	= 1;
                 port->settings.usb.interface	= 1;
@@ -300,6 +334,7 @@ gp_port_vusb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
                 port->settings.usb.maxpacketsize = 512;
 		return GP_OK;
 	}
+#endif
         return GP_ERROR_IO_USB_FIND;
 }
 
