@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,1,4,52],
 "gphoto2-filesys_8h.html#a75d0f5c804d7ea9274729202913aa472":[2,0,1,4,11],
 "gphoto2-filesys_8h.html#a7bbfa59b2587d36fa5be529c788f9585":[2,0,1,4,37],
 "gphoto2-filesys_8h.html#a7e4db0952402346bf8c8c6a51581efec":[2,0,1,4,17],
@@ -248,6 +249,5 @@ var NAVTREEINDEX2 =
 "gphoto2-port-result_8h.html#af56f93684bc8145a14a17d68ea20d589":[2,0,3,0,4,20],
 "gphoto2-port-result_8h.html#afd4a48ebc75390ed40bdf4b5cc30b258":[2,0,3,0,4,14],
 "gphoto2-port-result_8h_source.html":[2,0,3,0,4],
-"gphoto2-port-version_8c.html":[2,0,3,1,5],
-"gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,1,5,0]
+"gphoto2-port-version_8c.html":[2,0,3,1,5]
 };
